@@ -2,6 +2,7 @@ import torch
 import torch.nn as nn
 import torchvision.models as models
 import torchvision.transforms as transforms
+from lightwood.helpers.device import get_devices
 
 from lightwood.config.config import CONFIG
 
@@ -24,11 +25,7 @@ class Img2Vec():
         :param layer: String or Int depending on model.  See more docs: https://github.com/christiansafka/img2vec.git
         :param layer_output_size: Int depicting the output size of the requested layer
         """
-        device_str = "cuda" if CONFIG.USE_CUDA else "cpu"
-        if CONFIG.USE_DEVICE is not None:
-            device_str = CONFIG.USE_DEVICE
-
-        self.device = torch.device(device_str)
+        self.device, _ = get_devices()
         self.layer_output_size = layer_output_size
         self.model_name = model
 
@@ -41,6 +38,11 @@ class Img2Vec():
                                               std=[0.229, 0.224, 0.225])
         self.to_tensor = transforms.ToTensor()
 
+    def to(self, device, available_devices):
+        self.device = device
+        self.model = self.model.to(self.device)
+        return self
+
     def get_vec(self, img, tensor=False):
         """ Get vector embedding from PIL image
         :param img: PIL Image
